# Configuring the Architecture Executive Dashboard
### On this page
  * [Global Filter](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard#global-filter)
  * [Views](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard#views)
  * [Creating a View](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard#creating-a-view)
  * [Managing Views](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard#managing-views)
  * [Best Practices](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard#best-practices)
  * [Start with Basic Filters](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard#start-with-basic-filters)
  * [Configure Advanced Filters](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard#configure-advanced-filters)
  * [Avoid Over-Scoping Filters](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard#avoid-over-scoping-filters)


Configure filters for the architecture executive dashboard to limit the scope of data used in KPI calculations.
To configure the architecture executive dashboard, click the three-dot icon in the upper-right corner and select **Dashboard Configuration**. This action takes you to the administration area, where you can configure the following:
  * **Global filter** : This filter applies to all fact sheet types used in KPI calculations.
  * **Views** : These are customizable inventory filters for specific fact sheet types used in KPI calculations.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio47b4a3b5a1534bb19dbccdee67c4f0ce_LowRes.gif)
Navigating to the Dashboard Configuration Page
